@@ -125,7 +125,15 @@ class zetl:
 
 		return ret
 
-	def log_script_error(self,lid,script_error,database='',script_output=''):
+	def log_script_error(self,lid,pscript_error,database='',pscript_output=''):
+		script_error = pscript_error
+		if len(pscript_error) > 250:
+			script_error = pscript_error[250:]
+
+		script_output = pscript_output
+		if len(pscript_output) > 8100:
+			script_output = pscript_output[-8100:]
+
 
 		usql = "UPDATE  " + self.DB_SCHEMA() + ".z_log SET database='" + database.replace("'",'`') + "', script_output = '" + script_output.replace("'","`") + "', script_error = '" + script_error.replace("'","`") + "', endtime = now()::timestamp WHERE id = " + str(lid) 
 		try:
@@ -174,7 +182,7 @@ class zetl:
 
 				try:
 					if script_variables['DB_TYPE'] != '': # dont use default connection
-						new_postgresdb = db()
+						new_postgresdb = postgres_db()
 						new_mysqldb = mysql_db()
 
 						if script_variables['DB_TYPE'].strip().upper() == 'POSTGRES':
